
var map;

function initializeMap(lat,lon,initialzoom,layer) {

	function OSMMapType() {}
	OSMMapType.prototype = {
		tileSize: new google.maps.Size(256,256),
		maxZoom: 18,
		getTile: function(coord, zoom, ownerDocument) {
			var tileUrl = 'http://tile.openstreetmap.org/' + zoom + '/' + coord.x + '/' + coord.y + '.png';

			var tile = ownerDocument.createElement('img');
			tile.width = this.tileSize.width;
			tile.height = this.tileSize.height;
			tile.src = tileUrl;

			return tile;
		}
	};
	OSMMapType.prototype.name = "OSM";
	OSMMapType.prototype.alt = "OpenStreetMap";

	function SvMapType() {}
	SvMapType.prototype = {
		tileSize: new google.maps.Size(256,256),
		maxZoom: 17,
		getTile: function(coord, zoom, ownerDocument) {
			var tileUrl = 'http://os.openstreetmap.org/sv/' + zoom + '/' + coord.x + '/' + coord.y + '.png';

			var tile = ownerDocument.createElement('img');
			tile.width = this.tileSize.width;
			tile.height = this.tileSize.height;
			tile.src = tileUrl;

			return tile;
		}
	};
	SvMapType.prototype.name = "OS";
	SvMapType.prototype.alt = "OS StreetView";

	function NpeMapType() {}
	NpeMapType.prototype = {
		tileSize: new google.maps.Size(256,256),
		maxZoom: 15,
		getTile: function(coord, zoom, ownerDocument) {
			var tileUrl = 'http://ooc.openstreetmap.org/npe/' + zoom + '/' + coord.x + '/' + coord.y + '.png';

			var tile = ownerDocument.createElement('img');
			tile.width = this.tileSize.width;
			tile.height = this.tileSize.height;
			tile.src = tileUrl;

			return tile;
		}
	};
	NpeMapType.prototype.name = "NPE";
	NpeMapType.prototype.alt = "New Popular Edition";

	function Os7MapType() {}
	Os7MapType.prototype = {
		tileSize: new google.maps.Size(256,256),
		maxZoom: 14,
		getTile: function(coord, zoom, ownerDocument) {
			var tileUrl = 'http://ooc.openstreetmap.org/os7/' + zoom + '/' + coord.x + '/' + coord.y + '.jpg';

			var tile = ownerDocument.createElement('img');
			tile.width = this.tileSize.width;
			tile.height = this.tileSize.height;
			tile.src = tileUrl;

			return tile;
		}
	};
	Os7MapType.prototype.name = "OS7";
	Os7MapType.prototype.alt = "7th Series OS";

	var myLatlng = new google.maps.LatLng(lat, lon);
	var myOptions = {
	  zoom: initialzoom,
	  center: myLatlng,
	  mapTypeId: google.maps.MapTypeId.ROADMAP,
	    mapTypeControlOptions: {
	      mapTypeIds: ['osm', 'npe', 'os7', 'sv'],
	      style: google.maps.MapTypeControlStyle.DEFAULT
	    }
	}

	map = new google.maps.Map(document.getElementById("map_canvas"), myOptions);
	map.mapTypes.set('osm', new OSMMapType());
	map.mapTypes.set('npe', new NpeMapType());
	map.mapTypes.set('os7', new Os7MapType());
	map.mapTypes.set('sv', new SvMapType());
	map.setMapTypeId(layer);

	myCopyrights = {}
	myCopyrights["osm"] = "<a href='http://www.openstreetmap.org/'>OpenStreetMap</a> &copy; OpenStreetMap contributors, <a href='http://creativecommons.org/licenses/by-sa/2.0/'>CC-BY-SA</a>"
	myCopyrights["npe"] = "<a href='http://www.npemap.org.uk/'>NPE maps by Richard Fairhurst et. al.</a>"
	myCopyrights["os7"] = "<a href='http://steve8.dev.openstreetmap.org/os7.htm'>7th Series Maps from Steve, Tim et. al.</a>"
	myCopyrights["sv"] = "OS StreetView is Crown Copyright &copy; used under <a href=\'http://www.ordnancesurvey.co.uk/opendata/\'>OS OpenData</a>"

	copyrightDiv = document.createElement("div")
	copyrightDiv.id = "map-copyright"
	copyrightDiv.style.fontSize = "11px"
	copyrightDiv.style.fontFamily = "Arial, sans-serif"
	copyrightDiv.style.margin = "0 2px 2px 0"
	copyrightDiv.style.whiteSpace = "nowrap"
	copyrightDiv.innerHTML = myCopyrights[layer]
	map.controls[google.maps.ControlPosition.BOTTOM_LEFT].push(copyrightDiv)

	function onMapTypeChanged()
	{
	    newMapType = map.getMapTypeId()
	    copyrightDiv = document.getElementById("map-copyright")
		
	    if(newMapType in myCopyrights)
	    {

		copyrightDiv.innerHTML = myCopyrights[newMapType]
            }
	    else
		copyrightDiv.innerHTML = ""
	}

	google.maps.event.addListener(map, "maptypeid_changed", onMapTypeChanged)

}

function createMarker(lat,lon) {

	var latLng = new google.maps.LatLng(lat, lon);
	var marker = new google.maps.Marker({
	  position: latLng,
	  title: 'Point A',
	  map: map,
	  draggable: true
	});

	function updateMarkerPosition(latLng) {
	  /*document.getElementById('info').innerHTML = [
	    latLng.lat(),
	    latLng.lng()
	  ].join(', ');
	  document.getElementById('address').innerHTML = map.getMapTypeId();*/
		document.getElementById('lat').value = latLng.lat();
		document.getElementById('lon').value = latLng.lng();
		document.getElementById('layer').value = map.getMapTypeId();
	}

	updateMarkerPosition(latLng);

	  google.maps.event.addListener(marker, 'drag', function() {
	    //updateMarkerStatus('Dragging...');
	    updateMarkerPosition(marker.getPosition());
	  });

	  google.maps.event.addListener(map, 'click', function(event) {	    	
		marker.setPosition(event.latLng);
		updateMarkerPosition(event.latLng);
		map.setCenter(event.latLng);
		//placeMarker(event.latLng);
	  });
	  
    }

function createMapAndMarker(lat,lon,zoom,layer)
{
	initializeMap(lat,lon,zoom,layer);
	createMarker(lat,lon);
}

